<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="he">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>המצב המטוס מופעל</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>המצב המטוס לא מופעל</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>השבת</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>הפעל</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>המצב המטוס</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>הגדרות מצב המטוס</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>המצב המטוס</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>הכליים שלי</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>הגדרות בluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>נOFF</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>השבת</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>הפעל</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>הגדרות בluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 מחובר</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>הצורה...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>נOFF</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>%1 מחובר</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>לא מחובר</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>OFF</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>ברזות</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>הגדרות תצוגה</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>הגדרות תצוגה</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>ברזות</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>א׳</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>ב׳</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>שלישי</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>ד׳</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>חמישי</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>ו׳</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>ש׳</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>הוסף תפריט תקליטור</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>תאריך וזמן</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 שעות</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 שעות</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>הגדרות זמן</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>פתח את שולחן התאריכים</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>יום שני</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>יום שלישי</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>יום רביעי</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>יום חמישי</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>יום שישי</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>יום שבת</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>יום ראשון</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>יום שני</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>יום שלישי</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>יום רביעי</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>יום חמישי</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>יום שישי</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>יום שבת</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>יום ראשון</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>מכשירים אחרים</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>מצב DND</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>הגדרות מצב DND</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>ה DISABLE</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>ה אינבייל</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>מצב DND מופעל</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>מצב DND נדחה</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>מצב DND</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>راحة לعينים</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>راحة לعينים מופעלת</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>راحة לعينים נדחתה</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>הגדרות מסך</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>راحة לعينים</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>תema</translation>
    </message>
    <message>
        <source>On</source>
        <translation>במהלך</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>נfout</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>LTR</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>שחור</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>אוטומטי</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>השבת את המיטה לרגעים</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>הפעל את המיטה לרגעים</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>הגדרות מסך</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>תema:LTR</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>תema:שחור</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>תema:אוטומטי</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>השפעת חזותית</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>LTR</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>שחור</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>אוטומטי</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>תema</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>אין הודעות</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notification</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Settings</source>
        <translation>הגדרות</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Balanced</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Power Saver</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Battery</source>
        <translation>סוללה</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not charging</source>
        <translation>לא מטיל חשמל</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>מוכןเต็มly</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>טיל חשמל, %1 דקות עד מלא</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>טיל חשמל, %1 שעות ו%2 דקות עד מלא</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>מגניב %1, %2 שעות עד סיום</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>%1 שעות עד סיום</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>טיל חשמל %1, %2 שעות עד מלא</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>טיל חשמל, %1 שעות עד מלא</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>הגדרות החשמל</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>מוזיקה</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>לא ידוע</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>כיבוי</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>השהיה</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>תרדמת</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>נעילה</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>התנתקות</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>הגדרות החשמל</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>החלף את המחשב</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>עדכן וסגור</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>עדכן והחלף את המחשב</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>סגור</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>החל משתמש חדש</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>היום</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>לונאר</translation>
    </message>
    <message>
        <source>y</source>
        <translation>y,</translation>
    </message>
    <message>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <source>d</source>
        <translation>d</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Jan</source>
        <translation>ינו</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>פבר</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>מרץ</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>אפריל</translation>
    </message>
    <message>
        <source>May</source>
        <translation>מאי</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>יוני</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>יולי</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>אוגוסט</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>ספטמבר</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>אוקטובר</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>נובמבר</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>דצמבר</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>ה عليكון</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>יום שני</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>יום שלישי</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>יום רביעי</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>יום חמישי</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>יום שישי</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>יום שבת</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>יום ראשון</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>עוצמת קול</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>פלט</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>הגדרות קול</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>שמע</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>לא לה噤</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>לה噤</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>הגדרות קול</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>אין חלונות פלט</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>מגניב %1</translation>
    </message>
</context>
</TS>